@@ -2,11 +2,11 @@ package FunctionWipeout;
 use warnings;
 use strict;
 
-use ExporterTest qw(foo);
+use ExporterTest qw( foo qux $foo );
 
 sub bar { foo() }
 
-use namespace::clean;
+use namespace::clean -except => [qw( qux )];
 
 sub baz { bar() }
 
